HTML {
    PADDING-RIGHT: 0px; PADDING-LEFT: 0px; PADDING-BOTTOM: 0px; MARGIN: 0px; PADDING-TOP: 0px
}
BODY {
    PADDING-RIGHT: 0px; PADDING-LEFT: 0px; PADDING-BOTTOM: 0px; MARGIN: 0px; PADDING-TOP: 0px;
    BACKGROUND-COLOR: #ffffea;
}
.content {
    PADDING: 12px;
    MARGIN-TOP: 1px;  MARGIN-BOTTOM:0px;
    MARGIN-LEFT: 15px; MARGIN-RIGHT: 15px;
    BORDER-COLOR: #000000;
    BORDER-TOP: 0px;
    BORDER-BOTTOM: 0px;
    BORDER-LEFT: 1px;
    BORDER-RIGHT: 1px;
}

H1 {
    FONT-SIZE: 30pt; MARGIN: 0px;
    FONT-FAMILY: Optima, "Lucida Grande",Sans-serif;
    TEXT-ALIGN: center;
    PADDING-BOTTOM: 1em;
}
H2 {
    PADDING-RIGHT: 0.25em; PADDING-LEFT: 0.25em; FONT-SIZE: 16pt;
    PADDING-BOTTOM: 0.5em; MARGIN: 0px; PADDING-TOP: 0.1em;
FONT-FAMILY: Optima, "Lucida Grande",Sans-serif;
    TEXT-ALIGN: center;
}

A { text-decoration: none; color:#225 }
A:hover { text-decoration: underline; color:#222 }

table { 
border: 0px solid; 
background-color: #ffffff;

}
#matrix th {
background-color: #DDE;
border: 1px solid;
    font: bold 12px Verdana, sans-serif;
}

#matrix tr.alternate { background-color:#EEF; }
#matrix td {
    font: 12px Verdana, sans-serif;
}

#navlist
{
padding: 3px 0;
margin-left: 0;
border-bottom: 1px solid #778;
font: bold 12px Verdana, sans-serif;
}

#navlist li
{
list-style: none;
margin: 0;
display: inline;
}

#navlist li a
{
padding: 3px 0.5em;
margin-left: 3px;
border: 1px solid #778;
border-bottom: none;
background: #DDE;
text-decoration: none;
}

#navlist li a:link { color: #448; }
#navlist li a:visited { color: #667; }

#navlist li a:hover
{
color: #000;
background: #AAE;
border-color: #227;
}

#navlist li a#current
{
background: white;
border-bottom: 1px solid white;
}

td { font: 12px Verdana, sans-serif; }
.field {
background-color: #DDE;
border: 1px solid;
font-weight: bold;
}

#vlist
{
padding: 0 1px 1px;
margin-left: 0;
font: bold 12px Verdana, sans-serif;
background: gray;
width: 13em;
}

#vlist li
{
list-style: none;
margin: 0;
border-top: 1px solid gray;
text-align: left;
}

#vlist li a
{
display: block;
padding: 0.25em 0.5em 0.25em 0.75em;
border-left: 1em solid #AAB;
background: #CCD;
text-decoration: none;
}
#vlist li a:hover { 
    border-color: #227;
}
.search {float:right; background: #ffa; padding-left: 5px; padding-right: 5px}
.list { width: 70%; }

.column-wrap { position: relative; }
.leftcolumn { position: absolute; left: 10px; top: 50px; width: 200px; 
    border-right: 1px dotted black;
}
.centercolumn { margin-left: 200px; margin-right: 300px; }
.rightcolumn { position: absolute; right: 0px; top: 50px; width: 300px; }

.messages {
    margin: 20px; padding: 3px; border: 1px solid black; 
    background: #ddd; 
    font: bold 12px Verdana, sans-serif;
}

.error { color: #d00; }

.chorus { font-style: italic; position: relative; margin-left:50px; }
